#!/bin/bash

if [ -z "$BASH_VERSION" ]; then
	echo >&2 "This script requires 'bash' shell"
	exit 1
fi

if [ "$(echo -e TEST)" = "-e TEST" ]; then
	IS_POSIX=1
fi

LP="$PWD"
D_VER='head'

fecho()
{
	if [ "$1" = "COL" ]; then
		shift
		color="$1"
		shift
	fi
	if [ -z "$IS_POSIX" ]; then
		echo -e "\\033[${color}m$*\\033[0m"
	else
		echo "$*"
	fi
}

if [ "$(id -u)" -ne 0 ]; then
	fecho COL 31 "Not enough permissions to uninstall. Please login as root."
	exit 1
fi

fecho COL 33 "Uninstalling driver"

if [ -f Makefile ]; then
	/usr/bin/make driver_uninstall
fi

if [ -d "/usr/src/paragon-ufsd-${D_VER}" ]; then
	dkms uninstall -m paragon-ufsd -v "${D_VER}"    >  dkms-uninstall.log 2>&1
	dkms remove -m paragon-ufsd -v "${D_VER}" --all >> dkms-uninstall.log 2>&1
	rm -rf "/usr/src/paragon-ufsd-${D_VER}"
	rm -rf "/var/lib/dkms/paragon-ufsd"
fi

rm -f /etc/modules-load.d/paragon-ufsd.conf
if [ -f /etc/modules ]; then
	sed -i -e '/^jnl$/d' -e '/^ufsd$/d' /etc/modules
fi

find "/lib/modules/$(uname -r)" \( -name jnl.ko -o -name ufsd.ko \) -delete
depmod -a

fecho COL 33 "Driver uninstalled!"

if [ -f util/mount.paragon-ufsd ]; then
	fecho COL 33 "Removing automount scripts"
	rm -f /usr/sbin/mount.paragon-ufsd

	paths="$(readlink -e /sbin)"$'\n'"$(readlink -e /usr/sbin)"

	for p in $(echo "$paths" | sort -u); do
		for fs in mount.ntfs mount.hfsplus; do
			rm -f "$p/$fs"
			if [ -f "$p/$fs.bak" ]; then
				mv "$p/$fs.bak" "$p/$fs"
			fi
		done
	done
fi

if [ -d linutil ]; then
	fecho COL 33 "Would you like to uninstall NTFS/HFS+ utilites? [yes/no]"
	read -r answer
	case "$answer" in
		[yY]|[yY][eE][sS])
			if [ -d /usr/src/paragon-ufsd-${D_VER}/linutil/ ]; then
				cd "/usr/src/paragon-ufsd-${D_VER}/linutil/" &&
				/usr/bin/make remove
				cd "$LP" || exit 1
			else
				cd linutil/ &&
				/usr/bin/make remove
			fi

			fecho COL 33 "Utilities uninstalled!"
		;;
	esac
fi

